@@ -7,19 +7,17 @@ class Contact(BaseModel):
     """Contact information for the exposed API."""
 
     name: Optional[str] = None
-    """
-    The identifying name of the contact person/organization.
-    """
+    """The identifying name of the contact person/organization."""
 
     url: Optional[AnyUrl] = None
-    """
-    The URL pointing to the contact information.
+    """The URL pointing to the contact information.
+
     MUST be in the form of a URL.
     """
 
     email: Optional[Union[EmailStr, str]] = None
-    """
-    The email address of the contact person/organization.
+    """The email address of the contact person/organization.
+
     MUST be in the form of an email address.
     """
 
